"""Console script for deluge_cmd."""

import click


@click.command()
def main():
    """Main entrypoint."""
    click.echo("deluge_cmd:cli")
    click.echo("=" * len("deluge_cmd:cli"))
    click.echo("cli does nothing - use deluge_dls instead")


if __name__ == "__main__":
    main()  # pragma: no cover



#!/usr/bin/env python
"""Tests for `deluge_cmd` package."""

# from unittest import mock, skip
# from deluge_cmd import deluge_dls
# from collections import namedtuple


# args_tuple = namedtuple('args', 'type root pattern debug')
# @mock.patch('deluge_cmd.deluge_dls.list_deluge_fs', return_value=[])
# def test_command_line_interface(mocked):
#     """Test the CLI."""
#     args = args_tuple('a', '.', '*', '')
#     deluge_dls.handle_args(args)
#     assert mocked.call_count == 1



"""Main dsd script."""
# flake8: noqa
import argparse

from deluge_card import list_deluge_fs


def list_songs(card, args):
    songs = list(card.songs(args.pattern))
    if args.summary | args.verbose:
        print(f'Deluge filesystem {card} has {len(songs)} songs')
    if args.summary:
        return
    for s in songs:
        print(f'  {s} key {s.scale()} tempo {s.tempo()}')


def list_samples(card, args):
    samples = list(card.samples(args.pattern))
    if args.summary | args.verbose:
        print(f'Deluge filesystem {card} has {len(samples)} samples')
    if args.summary:
        return
    for sa in samples:
        print(f'  {sa}')


def list_song_samples(card, args):
    songs = list(card.songs())
    for s in songs:
        if args.summary | args.verbose:
            print(f'{s} has {len(list(s.samples(args.pattern)))} samples')
        if args.summary:
            continue
        for sa in s.samples(args.pattern):
            print(f'  {s} {str(sa)}')


def parse_args():
    parser = argparse.ArgumentParser(description='deluge_dls.py (dls)  - list deluge FS contents')
    parser.add_argument('type', help='one of of s=songs, a=samples, ss=song_samples (future: k=kits, i=instruments)')
    parser.add_argument('root', help='root folder to begin ls from')
    parser.add_argument('pattern', help='pattern')
    parser.add_argument("-v", "--verbose", help="increase output verbosity", action="store_true")
    parser.add_argument("-s", "--summary", help="summarise output", action="store_true")
    parser.add_argument('-D', '--debug', action="store_true", help="print debug statements")
    args = parser.parse_args()
    return args


def main(args):
    if args.debug:
        print(f"Args: {args}")

    card_imgs = list(list_deluge_fs(args.root))
    if len(card_imgs):
        for c in card_imgs:
            print(f'Deluge filesystem at {c.card_root} mounted: {c.is_mounted()}')
            if args.type.lower() in ['s', 'songs']:
                list_songs(c, args)
            if args.type.lower() in ['a', 'samples']:
                list_samples(c, args)
            if args.type.lower() in ['ss', 'song_samples']:
                list_song_samples(c, args)


if __name__ == '__main__':
    main(parse_args())  # pragma: no cover



#!/usr/bin/env python
"""Tests for `deluge_cmd` package."""

from unittest import mock, skip
from deluge_cmd import deluge_dls, deluge_dmv
from collections import namedtuple

dls_args_tuple = namedtuple('dls_args_tuple', 'type root pattern debug')


@mock.patch('deluge_cmd.deluge_dls.list_deluge_fs', return_value=[])
def test_dls_command_line_interface(mocked):
    args = dls_args_tuple('a', '.', '*', '')
    deluge_dls.main(args)
    assert mocked.call_count == 1


dmv_args_tuple = namedtuple('dmv_args_tuple', 'root pattern dest debug')


@mock.patch('deluge_cmd.deluge_dmv.list_deluge_fs', return_value=[])
def test_dmv_command_line_interface(mocked):
    args = dmv_args_tuple('.', '*', 'SAMPLE/NEW', '')
    deluge_dmv.main(args)
    assert mocked.call_count == 1



"""Main dmv script."""
# flake8: noqa
import argparse
import itertools
from pathlib import Path

from deluge_card import list_deluge_fs
from deluge_card.deluge_sample import mv_samples, validate_mv_dest


def parse_args():
    parser = argparse.ArgumentParser(description='deluge_dmv.py (dmv)  - move deluge FS sample contents.')
    parser.add_argument('root', help='root folder, must be a valid Deluge file system.')
    parser.add_argument('pattern', help='glob pattern to match e.g. **/Clap*.wav')
    parser.add_argument('dest', help='target folder or file, which must be in a subfolder of root.')
    parser.add_argument("-v", "--verbose", help="increase output verbosity", action="store_true")
    parser.add_argument("-s", "--summary", help="summarise output", action="store_true")
    parser.add_argument('-D', '--debug', action="store_true", help="print debug statements")
    args = parser.parse_args()
    return args


def main(args):
    """Main entrypoint."""
    if args.debug:
        print(f"Args: {args}")

    card_imgs = list(list_deluge_fs(args.root))
    if len(card_imgs) == 0:
        print('No card found.')
        return
    if len(card_imgs) > 1:
        print("Oops multiple cards found, only a single card mv is supported.")
        return

    card = card_imgs[0]
    try:
        validate_mv_dest(card.card_root, Path(args.dest))
        song_samples = itertools.chain.from_iterable(map(lambda song: song.samples(), card.songs()))
        new_path = Path(args.dest)
    except ValueError as err:
        print(err)
        return

    counters = dict(move_file=0, update_song_xml=0)
    for modop in mv_samples(card.card_root, song_samples, args.pattern, new_path):
        counters[modop.operation] += 1
        if args.verbose:
            print(f"{str(modop.path)} {modop.operation.replace('_', ' ')}")

    if args.summary | args.verbose:
        print(f'moved {counters["move_file"]} samples, in {counters["update_song_xml"]} songs')


if __name__ == '__main__':
    main(parse_args())  # pragma: no cover



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['deluge_cmd', 'tests']

package_data = \
{'': ['*']}

install_requires = \
['click>=8.1.3,<9.0.0', 'deluge-card>=0.4.2,<0.5.0']

entry_points = \
{'console_scripts': ['dls = deluge_cmd.deluge_dls:main',
                     'dmv = deluge_cmd.deluge_dmv:main']}

setup_kwargs = {
    'name': 'deluge-cmd',
    'version': '0.3.1',
    'description': 'Command line tools to manage Synthstrom deluge SD card contents.',
    'long_description': '# deluge-cmd\n\n[![pypi](https://img.shields.io/pypi/v/deluge-cmd.svg)](https://pypi.org/project/deluge-cmd/)\n[![python](https://img.shields.io/pypi/pyversions/deluge-cmd.svg)](https://pypi.org/project/deluge-cmd/)\n[![Build Status](https://github.com/mupaduw/deluge-cmd/actions/workflows/dev.yml/badge.svg)](https://github.com/mupaduw/deluge-cmd/actions/workflows/dev.yml)\n[![codecov](https://codecov.io/gh/mupaduw/deluge-cmd/branch/main/graphs/badge.svg)](https://codecov.io/github/mupaduw/deluge-cmd)\n\n\nSome cli tools to manage Synthstrom Deluge SD card contents.\n\n* Documentation: <https://mupaduw.github.io/deluge-cmd>\n* GitHub: <https://github.com/mupaduw/deluge-cmd>\n* PyPI: <https://pypi.org/project/deluge-cmd/>\n* Free software: MIT\n\nThis project uses [deluge-card](https://github.com/mupaduw/deluge-card) which provides a python API for the Deluge Folder System.\n\n## Features\n\n- list Songs Samples, and Song Samples on a Deluge Folder System (DFS).\n- check Deluge Folder Systems.\n- list useful attributes tempo, key, scale.\n- filter on path patterns: e.g. list all "Kick" samples).\n\ne.g.\n\n```\n$> dls songs ~/Music/DELUGE/01 *001*\nDeluge filesystem at /homie/Music/DELUGE/01 mounted: False\n  DelugeSong(/homie/Music/DELUGE/01/SONGS/SONG001.XML) key C major tempo 96.0\n  DelugeSong(/homie/Music/DELUGE/01/SONGS/SONG001A.XML) key C major tempo 96.0\n  DelugeSong(/homie/Music/DELUGE/01/SONGS/SONG001B.XML) key C major tempo 108.0\n  DelugeSong(/homie/Music/DELUGE/01/SONGS/SONG001C.XML) key C major tempo 108.0\n  DelugeSong(/homie/Music/DELUGE/01/SONGS/SONG001D.XML) key C major tempo 96.0\n```\n\n## Experimental (backup first!)\n\n> Move your samples, and update the songs that reference them\n> \n> which has some [missing prime-time features](https://github.com/mupaduw/deluge-card/issues/14)\n\n```\n$> dmv ~/Music/DELUGE/TEST/02 **/CR78* SAMPLES/ANOTHER_PLACE -vs\n~/Music/DELUGE/TEST/02/SONGS/SONG002A.XML update song xml\n~/Music/DELUGE/TEST/02/SONGS/SONG002.XML update song xml\n...\n~/Music/DELUGE/TEST/02/SAMPLES/ANOTHER_PLACE/CR78 Closed hihat.wav move file\n~/Music/DELUGE/TEST/02/SAMPLES/ANOTHER_PLACE/CR78 Metal.wav move file\nmoved 14 samples, in 9 songs\n```\n\n### Planned features\n- (d)cp, and (d)rm commands.\n- support for v4.0+ nested folders\n- song groups (1, 1A, 1B, 1C).\n- instruments, kits & synths.\n\n\n## Credits\n\nThis package was created with [Cookiecutter](https://github.com/audreyr/cookiecutter) and the [waynerv/cookiecutter-pypackage](https://github.com/waynerv/cookiecutter-pypackage) project template.\n',
    'author': 'Chris B Chamberlain',
    'author_email': 'chrisbc@artisan.co.nz',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/mupaduw/deluge-cmd',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
